@@ -1,7 +1,7 @@
 #*********************************************************************
 #*** ResourcePool
-#*** Copyright (c) 2002-2005 by Markus Winand <mws@fatalmind.com>
-#*** $Id: ResourcePool.pm,v 1.49.2.4 2005/01/05 19:42:49 mws Exp $
+#*** Copyright (c) 2002,2003 by Markus Winand <mws@fatalmind.com>
+#*** $Id: ResourcePool.pm,v 1.51 2003-03-18 23:29:27 mws Exp $
 #*********************************************************************
 
 ######
@@ -16,7 +16,6 @@ package ResourcePool;
 
 use strict;
 use vars qw($VERSION @ISA);
-use Tie::RefHash;
 use ResourcePool::Singleton;
 use ResourcePool::Command::Execute;
 
@@ -27,7 +26,7 @@ BEGIN {
 
 
 push @ISA, ("ResourcePool::Command::Execute", "ResourcePool::Singleton");
-$VERSION = "1.0104";
+$VERSION = "1.0102";
  
 sub new($$@) {
 	my $proto = shift;
@@ -38,7 +37,7 @@ sub new($$@) {
 	if (!exists($self->{Factory})) {
 		$self->{Factory} = $factory;
 		$self->{FreePool} = [];
-		tie %{ $self->{UsedPool} }, 'Tie::RefHash';
+		$self->{UsedPool} = {};
 		$self->{FreePoolSize} = 0;
 		$self->{UsedPoolSize} = 0;
 		my %options = (
